@@ -55,6 +55,13 @@ EXPLOSION::EXPLOSION (GLOBALDATA *global, ENVIRONMENT *env, double xpos, double
   player = NULL;
   _align = LEFT;
   _global = global;
+  #ifdef NETWORK
+  /*
+  char buffer[256];
+  sprintf(buffer, "EXPLOSION %d %d %d", (int) xpos, (int) ypos, weaponType);
+  global->Send_To_Clients(buffer);
+  */
+  #endif
   x = xpos;
   y = ypos;
   type = weaponType;
@@ -393,8 +400,9 @@ void EXPLOSION::draw (BITMAP *dest)
       if (a > 1 && a <= EXPLODEFRAMES + 1)
         {
           int startCirc = (radius / EXPLODEFRAMES) * a;
+          int colour = (player) ? player->color : makecol(0, 0, 255);
           circlefill (_env->terrain, (int)x, (int)y, startCirc, PINK);
-          circle (dest, (int)x, (int)y, startCirc, player->color);
+          circle (dest, (int)x, (int)y, startCirc, colour);
           setUpdateArea ((int)x - (radius + 1), (int)y - (radius + 1), (radius + 1) * 2, (radius + 1) * 2);
         }
     }
